ButtonItem — pyqtgraph 0.11.0rc0 documentation

# ButtonItem

class `pyqtgraph.` `ButtonItem`(imageFile=None, width=None, parentItem=None, pixmap=None)

  Button graphicsItem displaying an image.

  `__init__`(imageFile=None, width=None, parentItem=None, pixmap=None)

    Initialize self. See help(type(self)) for accurate signature.

  `boundingRect`(self) → PySide2.QtCore.QRectF
  `paint`(self, painter: PySide2.QtGui.QPainter, option: PySide2.QtWidgets.QStyleOptionGraphicsItem, widget: typing.Union[PySide2.QtWidgets.QWidget, NoneType] = None)